<?php

declare(strict_types=1);

namespace App\Http\Requests\Category;

use App\Http\Requests\InvalidDataResponseTrait;
use App\Services\QueryRequestModifiers\Category\CategoryFilter;
use App\Services\QueryRequestModifiers\Category\CategoryFilterDTO;
use App\Services\QueryRequestModifiers\Category\CategoryOrder;
use App\Services\QueryRequestModifiers\Category\CategoryOrderDTO;
use Illuminate\Foundation\Http\FormRequest;

class ListCategoryRequest extends FormRequest
{
    use InvalidDataResponseTrait;

    public function __construct(
        private readonly CategoryOrder $categoryOrder,
        private readonly CategoryFilter $categoryFilter,
    ) {
    }


    /**
     * @return array<string, string>
     */
    public function all($keys = null): array
    {
        $request = parent::all($keys);

        $request['page'] = $this->route('page');

        return $request;
    }

    public function authorize(): bool
    {
        return true;
    }

    /**
     * @return array<string, string>
     */
    public function rules(): array
    {
        return [
            'page' => 'required|integer|min:1',
            ... $this->categoryOrder->validateRules(),
            ... $this->categoryFilter->validateRules()
        ];
    }


    /**
     * @return array<string, string>
     */
    public function attributes(): array
    {
        return [
            'page' => 'page number',
        ];
    }

    public function filters(): ?CategoryFilterDTO
    {
        return $this->categoryFilter->makeFromRequest($this);
    }

    public function order(): ?CategoryOrderDTO
    {
        return $this->categoryOrder->makeFromRequest($this);
    }
}
