<?php

declare(strict_types=1);

namespace App\Services\QueryRequestModifiers\Category;

use App\Http\Requests\Category\ListCategoryRequest;
use App\Models\Category;
use App\Services\QueryRequestModifiers\Filterable;
use Illuminate\Database\Eloquent\Builder;

class CategoryFilter
{
    /**
     * @use Filterable<Category, CategoryFilterDTO>
     */
    use Filterable;

    /**
     * @param Builder<Category> $query
     * @return Builder<Category>
     */
    public function apply(Builder $query, ?CategoryFilterDTO $filters): Builder
    {
        return $this->applyFilterable($query, $filters);
    }

    public function makeFromRequest(ListCategoryRequest $request): ?CategoryFilterDTO
    {
        return $this->makeFilterableFromRequest($request, CategoryFilterDTO::class);
    }

    /**
     * @return array<string, string>
     */
    public function validateRules(): array
    {
        return [
            'name' => 'sometimes|string|max:255',
        ];
    }


    /**
     * @return array<int, string>
     */
    protected static function keys(): array
    {
        return ['name'];
    }
}
