<?php

declare(strict_types=1);

namespace App\Services\QueryRequestModifiers\Comment;

use App\Http\Requests\Comment\ListCommentRequest;
use App\Models\Comment;
use App\Services\QueryRequestModifiers\Filterable;
use Illuminate\Database\Eloquent\Builder;

class CommentFilter
{
    /**
     * @use Filterable<Comment, CommentFilterDTO>
     */
    use Filterable;

    /**
     * @param Builder<Comment> $query
     * @return Builder<Comment>
     */
    public function apply(Builder $query, ?CommentFilterDTO $filters): Builder
    {
        return $this->applyFilterable($query, $filters);
    }

    public function makeFromRequest(ListCommentRequest $request): ?CommentFilterDTO
    {
        return $this->makeFilterableFromRequest($request, CommentFilterDTO::class);
    }

    /**
     * @return array<string, string>
     */
    public function validateRules(): array
    {
        return [
            'content' => 'sometimes|string',
        ];
    }


    /**
     * @return array<int, string>
     */
    protected static function keys(): array
    {
        return ['content'];
    }
}
