<?php

declare(strict_types=1);

namespace App\Services\QueryRequestModifiers;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Foundation\Http\FormRequest;

/**
 * @template C of Model
 * @template D
 */
trait Filterable
{
    abstract public static function keys();

    /**
     * @param Builder<C>  $query
     * @return Builder<C>
     */
    protected function applyFilterable(Builder $query, ?object $filters): Builder
    {
        if ($filters === null) {
            return $query;
        }

        foreach (self::keys() as $filterName) {
            if (isset($filters->filters[$filterName])) {
                $query->where($filterName, '=', $filters->filters[$filterName]);
            }
        }
        return $query;
    }

    /**
     * @param class-string<D> $className
     * @return D|null
     */
    protected function makeFilterableFromRequest(FormRequest $request, string $className): ?object
    {
        $keys = $request->all(self::keys());

        // no filtering
        if (count($keys) === 0) {
            return null;
        }

        return new $className($keys);
    }
}
